import { Tickets } from './tickets.types';
import { RsvpForm, RsvpForm } from './rsvpform.types';
import { Rsvp } from './rsvp.types';
import { Form } from './form.types';
/**
 * **Deprecated:** Creates a new RSVP form for the specified event.
 *
 * **Deprecation note:** The `createEventRsvpForm()` function is being deprecated. Use
 *  the [`getForm()`](#getForm) function instead.
 *
 *  Use the `createEventRsvpForm()` function to retrieve the information
 *  you need to [create a custom RSVP form](https://dev.wix.com/docs/velo/api-reference/wix-events-frontend/rsvp/introduction)
 *  for a specified event and to submit the form data to register guests for the event.
 *
 *  Retrieve event IDs to specify an event from the **Events/Events** collection.
 * > **Note:**
 *  To work with the Wix Events API, you need to publish your site.
 * @param eventId - ID of the event to create an RSVP form for.
 * @requiredField eventId
 * @returns An RSVP form object.
 * @servicePath wix-events-frontend.RsvpForm
 */
export function createEventRsvpForm(eventId: string): Promise<RsvpForm>;
/**
 * Gets a new registration form for the specified event.
 *
 * Use the `getForm()` function to retrieve the information
 *  you need to [create a custom registration form](events/form)
 *  for a specified event.
 *
 *  Retrieve event IDs from the **Events/Events** collection to specify which event's form to get.
 * > **Note:**
 *  To work with the Wix Events API, you need to publish your site.
 * @param eventId - ID of the event to get a registration form for.
 * @requiredField eventId
 * @returns Fulfilled - A registration form object for the specified event.
 * @servicePath wix-events-frontend.Form
 */
export function getForm(eventId: string): Promise<Form>;
